@@ -8,7 +8,7 @@ from .aws_client import AWSClient
 
 # Initialize sentry, logger and AWS X-Ray
 def handler_decorator(handler):
-  def wrapper(aws_client, *args):
+  def wrapper(event, context, aws_client: AWSClient):
     
     # Logger
     logger = logging.getLogger()
@@ -27,9 +27,9 @@ def handler_decorator(handler):
       traces_sample_rate=1.0
     )
     try:
-      return handler(aws_client, *args)
+      return handler(event, context, aws_client)
     except Exception as err:
-      sentry_sdk.capture_exception(err)
+      sentry_sdk.capture_exception(str(err))
       client = sentry_sdk.Hub.current.client
       if client is not None:
         client.flush(timeout=1)
